# Generated by roxygen2: do not edit by hand

S3method(as.logical,ggspec_result)
S3method(print,ggspec_canon)
S3method(print,ggspec_compare)
S3method(print,ggspec_result)
export(assert_ggplot)
export(canon)
export(check_plot)
export(compare_conceptual)
export(compare_plots)
export(compare_visual)
export(enrich_spec)
export(equiv_aes)
export(equiv_coord)
export(equiv_data)
export(equiv_facets)
export(equiv_labels)
export(equiv_layers)
export(equiv_params)
export(equiv_plot)
export(equiv_rendered)
export(equiv_scales)
export(expect_equiv_plot)
export(has_layer)
export(is_ggplot)
export(mapping_exists)
export(n_layers)
export(spec_aes)
export(spec_coord)
export(spec_data)
export(spec_facets)
export(spec_labels)
export(spec_layers)
export(spec_plot)
export(spec_scales)
